@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2004 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2005 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 """Produce and process the pending-approval items for a list."""
 
@@ -688,9 +689,9 @@ def process_form(mlist, doc, cgidata):
                 senderactions.setdefault(sender, {})[action] = value
     # discard-all-defers
     try:
-	discardalldefersp = cgidata.getvalue('discardalldefersp', 0)
+        discardalldefersp = cgidata.getvalue('discardalldefersp', 0)
     except ValueError:
-	discardalldefersp = 0
+        discardalldefersp = 0
     for sender in senderactions.keys():
         actions = senderactions[sender]
         # Handle what to do about all this sender's held messages
@@ -698,8 +699,8 @@ def process_form(mlist, doc, cgidata):
             action = int(actions.get('senderaction', mm_cfg.DEFER))
         except ValueError:
             action = mm_cfg.DEFER
-	if action == mm_cfg.DEFER and discardalldefersp:
-	    action = mm_cfg.DISCARD
+        if action == mm_cfg.DEFER and discardalldefersp:
+            action = mm_cfg.DISCARD
         if action in (mm_cfg.DEFER, mm_cfg.APPROVE,
                       mm_cfg.REJECT, mm_cfg.DISCARD):
             preserve = actions.get('senderpreserve', 0)
@@ -745,6 +746,7 @@ def process_form(mlist, doc, cgidata):
             if sender not in mlist.ban_list:
                 mlist.ban_list.append(sender)
     # Now, do message specific actions
+    banaddrs = []
     erroraddrs = []
     for k in cgidata.keys():
         formv = cgidata[k]
@@ -794,8 +796,14 @@ def process_form(mlist, doc, cgidata):
             continue
         except Errors.MMAlreadyAMember, v:
             erroraddrs.append(v)
+        except Errors.MembershipIsBanned, pattern:
+            sender = mlist.GetRecord(request_id)[1]
+            banaddrs.append((sender, pattern))
     # save the list and print the results
     doc.AddItem(Header(2, _('Database Updated...')))
     if erroraddrs:
         for addr in erroraddrs:
             doc.AddItem(`addr` + _(' is already a member') + '<br>')
+    if banaddrs:
+        for addr, patt in banaddrs:
+            doc.AddItem(_('%(addr)s is banned (matched: %(patt)s)') + '<br>')
