@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2004 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2005 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 
 """Mixin class with message delivery routines."""
@@ -197,7 +198,6 @@ is required.""")))
         d = {'listname': listname,
              'address': member,
              'optionsurl': self.GetOptionsURL(member, absolute=True),
-             'password': self.getMemberPassword(member),
              'owneraddr': self.GetOwnerEmail(),
              }
         text = Utils.maketext('probe.txt', d,
@@ -220,7 +220,8 @@ is required.""")))
             subject = _('%(listname)s mailing list probe message')
         finally:
             i18n.set_translation(otrans)
-        outer = Message.UserNotification(member, probeaddr, subject)
+        outer = Message.UserNotification(member, probeaddr, subject,
+                                         lang=ulang)
         outer.set_type('multipart/mixed')
         text = MIMEText(text, _charset=Utils.GetCharSet(ulang))
         outer.attach(text)
