@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2005 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2006 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 
 """The class representing a Mailman mailing list.
@@ -209,7 +210,8 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
 
     def GetConfirmJoinSubject(self, listname, cookie):
         if mm_cfg.VERP_CONFIRMATIONS and cookie:
-            cset = Utils.GetCharSet(self.preferred_language)
+            cset = i18n.get_translation().charset() or \
+                       Utils.GetCharSet(self.preferred_language)
             subj = Header(
      _('Your confirmation is required to join the %(listname)s mailing list'),
                           cset, header_name='subject')
@@ -219,7 +221,8 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
 
     def GetConfirmLeaveSubject(self, listname, cookie):
         if mm_cfg.VERP_CONFIRMATIONS and cookie:
-            cset = Utils.GetCharSet(self.preferred_language)
+            cset = i18n.get_translation().charset() or \
+                       Utils.GetCharSet(self.preferred_language)
             subj = Header(
      _('Your confirmation is required to leave the %(listname)s mailing list'),
                           cset, header_name='subject')
@@ -363,6 +366,7 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
             mm_cfg.DEFAULT_FILTER_FILENAME_EXTENSIONS
         self.pass_filename_extensions = mm_cfg.DEFAULT_PASS_FILENAME_EXTENSIONS
         self.filter_content = mm_cfg.DEFAULT_FILTER_CONTENT
+        self.collapse_alternatives = mm_cfg.DEFAULT_COLLAPSE_ALTERNATIVES
         self.convert_html_to_plaintext = \
             mm_cfg.DEFAULT_CONVERT_HTML_TO_PLAINTEXT
         self.filter_action = mm_cfg.DEFAULT_FILTER_ACTION
@@ -763,6 +767,10 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
         """
         invitee = userdesc.address
         Utils.ValidateEmail(invitee)
+        # check for banned address
+        pattern = self.GetBannedPattern(invitee)
+        if pattern:
+            raise Errors.MembershipIsBanned, pattern
         # Hack alert!  Squirrel away a flag that only invitations have, so
         # that we can do something slightly different when an invitation
         # subscription is confirmed.  In those cases, we don't need further
@@ -836,29 +844,13 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
         if email.lower() == self.GetListEmail().lower():
             # Trying to subscribe the list to itself!
             raise Errors.MMBadEmailError
-
+        realname = self.real_name
         # Is the subscribing address banned from this list?
-        ban = 0
-        for pattern in self.ban_list:
-            if pattern.startswith('^'):
-                # This is a regular expression match
-                try:
-                    if re.search(pattern, email, re.IGNORECASE):
-                        ban = 1
-                        break
-                except re.error:
-                    # BAW: we should probably remove this pattern
-                    pass
-            else:
-                # Do the comparison case insensitively
-                if pattern.lower() == email.lower():
-                    ban = 1
-                    break
-        if ban:
-            syslog('vette', 'banned subscription: %s (matched: %s)',
-                   email, pattern)
+        pattern = self.GetBannedPattern(email)
+        if pattern:
+            syslog('vette', '%s banned subscription: %s (matched: %s)',
+                   realname, email, pattern)
             raise Errors.MembershipIsBanned, pattern
-
         # Sanity check the digest flag
         if digest and not self.digestable:
             raise Errors.MMCantDigestError
@@ -888,7 +880,6 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
                 remote = _(' from %(remote)s')
 
             recipient = self.GetMemberAdminEmail(email)
-            realname = self.real_name
             confirmurl = '%s/%s' % (self.GetScriptURL('confirm', absolute=1),
                                     cookie)
             text = Utils.maketext(
@@ -960,6 +951,11 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
         Utils.ValidateEmail(email)
         if self.isMember(email):
             raise Errors.MMAlreadyAMember, email
+        # Check for banned address here too for admin mass subscribes
+        # and confirmations.
+        pattern = self.GetBannedPattern(email)
+        if pattern:
+            raise Errors.MembershipIsBanned, pattern
         # Do the actual addition
         self.addNewMember(email, realname=name, digest=digest,
                           password=password, language=lang)
@@ -973,7 +969,7 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
         else:
             kind = ''
         syslog('subscribe', '%s: new%s %s, %s', self.internal_name(),
-               kind, formataddr((email, name)), whence)
+               kind, formataddr((name, email)), whence)
         if ack:
             self.SendSubscribeAck(email, self.getMemberPassword(email),
                                   digest, text)
@@ -1072,12 +1068,21 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
             raise Errors.MMAlreadyAMember
         if newaddr == self.GetListEmail().lower():
             raise Errors.MMBadEmailError
+        realname = self.real_name
+        # Don't allow changing to a banned address. MAS: maybe we should
+        # unsubscribe the oldaddr too just for trying, but that's probably
+        # too harsh.
+        pattern = self.GetBannedPattern(newaddr)
+        if pattern:
+            syslog('vette',
+                   '%s banned address change: %s -> %s (matched: %s)',
+                   realname, oldaddr, newaddr, pattern)
+            raise Errors.MembershipIsBanned, pattern
         # Pend the subscription change
         cookie = self.pend_new(Pending.CHANGE_OF_ADDRESS,
                                oldaddr, newaddr, globally)
         confirmurl = '%s/%s' % (self.GetScriptURL('confirm', absolute=1),
                                 cookie)
-        realname = self.real_name
         lang = self.getMemberLanguage(oldaddr)
         text = Utils.maketext(
             'verify.txt',
@@ -1106,6 +1111,13 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
         msg.send(self)
 
     def ApprovedChangeMemberAddress(self, oldaddr, newaddr, globally):
+        # Check here for banned address in case address was banned after
+        # confirmation was mailed. MAS: If it's global change should we just
+        # skip this list and proceed to the others? For now we'll throw the
+        # exception.
+        pattern = self.GetBannedPattern(newaddr)
+        if pattern:
+            raise Errors.MembershipIsBanned, pattern
         # It's possible they were a member of this list, but choose to change
         # their membership globally.  In that case, we simply remove the old
         # address.
@@ -1126,6 +1138,9 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
                 continue
             if not mlist.isMember(oldaddr):
                 continue
+            # If new address is banned from this list, just skip it.
+            if mlist.GetBannedPattern(newaddr):
+                continue
             mlist.Lock()
             try:
                 # Same logic as above, re newaddr is already a member
@@ -1453,6 +1468,31 @@ bad regexp in bounce_matching_header line: %s
         self.hold_and_cmd_autoresponses[sender] = (today, count+1)
         return 1
 
+    def GetBannedPattern(self, email):
+        """Returns matched entry in ban_list if email matches.
+        Otherwise returns None.
+        """
+        ban = False
+        for pattern in self.ban_list:
+            if pattern.startswith('^'):
+                # This is a regular expression match
+                try:
+                    if re.search(pattern, email, re.IGNORECASE):
+                        ban = True
+                        break
+                except re.error:
+                    # BAW: we should probably remove this pattern
+                    pass
+            else:
+                # Do the comparison case insensitively
+                if pattern.lower() == email.lower():
+                    ban = True
+                    break
+        if ban:
+            return pattern
+        else:
+            return None
+
 
 
     #
