@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2005 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2006 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 """Standard Mailman message object.
 
@@ -188,6 +189,16 @@ class Message(email.Message.Message):
             authors.append(address)
         return authors
 
+    def get_filename(self, failobj=None):
+        """Some MUA have bugs in RFC2231 filename encoding and cause
+        Mailman to stop delivery in Scrubber.py (called from ToDigest.py).
+        """
+        try:
+            filename = email.Message.Message.get_filename(self, failobj)
+            return filename
+        except (UnicodeError, LookupError, ValueError):
+            return failobj
+
 
 
 class UserNotification(Message):
