@@ -26,15 +26,9 @@ except TestSkipped:
 
 # See if we have the Japanese codecs package installed
 try:
-    # Python 2.4
-    unicode('foo', 'euc-jp')
-except LookupError:
-    try:
-        unicode('foo', 'japanese.iso-2022-jp')
-    except LookupError:
-        test_email_codecs = None
-else:
     from email.test import test_email_codecs
+except TestSkipped:
+    test_email_codecs = None
 
 
 
